**[English](https://github.com/victordomingos/count-money/blob/master/README.md)** | [Portugu&ecirc;s](https://github.com/victordomingos/count-money/blob/master/README_PT.md)

# Count Money [![Github commits (since latest release)](https://img.shields.io/github/commits-since/victordomingos/count-money/latest.svg)](https://github.com/victordomingos/count-money) ![PyPI](https://img.shields.io/pypi/v/count-money) ![PyPI - Downloads](https://img.shields.io/pypi/dm/count-money)

![img](https://cloud.githubusercontent.com/assets/18650184/24195187/b04ff8ce-0ef0-11e7-8cec-9334a8cdd824.png)  
A little utility app to help you count coins and bills, which calculates in real-time the total amount of money.
Additionally, it can save a report in a text file containing both the totals and the individual amounts.

## Installation and dependencies:

To install and run this application, you just need to have a working
Python 3.6+ installation, with support for tkinter/ttk. The easiest way to install it in a single step is
by using this command:

```
pip3 install count-money
```

## How to use:

The current version of this aplication can be run from the command line shell using the following command:

```
count-money
```

